@@ -2,7 +2,9 @@ import abc
 import re
 
 from pdm.project import Config, Project
+from pdm.project.lockfile import FLAG_CROSS_PLATFORM
 from pdm.termui import Verbosity
+from pdm.utils import parse_version
 
 
 class BaseFixer(abc.ABC):
@@ -76,14 +78,50 @@ class PackageTypeFixer(BaseFixer):  # pragma: no cover
         dist = str(package_type == "library").lower()
         return (
             rf'[success]package-type = "{package_type}"[/] has been renamed to '
-            rf"[info]distribution = {dist}[/] under \[tool.pdm\] table"
+            rf"[info]distribution = {dist}[/] under \[tool.pdm] table"
         )
 
     def check(self) -> bool:
         return "package-type" in self.project.pyproject.settings
 
     def fix(self) -> None:
-        package_type = self.project.pyproject.settings.pop("package-type")
-        dist = str(package_type == "library").lower()
-        self.project.pyproject.settings["distribution"] = dist
+        # Copy the project settings
+        self.project.pyproject.open_for_write()
+        settings = self.project.pyproject.settings.copy()
+
+        # Pop the package type and convert it to a distribution type
+        package_type = settings.pop("package-type")
+        dist = package_type == "library"
+        settings["distribution"] = dist
+
+        # Update the project settings with the new distribution type
+        self.project.pyproject._data["tool"].pop("pdm")
+        self.project.pyproject.settings.update(settings)
+
+        # Write the updated settings back to the project
         self.project.pyproject.write(False)
+
+
+class LockStrategyFixer(BaseFixer):
+    identifier = "deprecated-cross-platform"
+
+    def get_message(self) -> str:
+        return "Lock strategy [success]`cross_platform`[/] has been deprecated in favor of lock targets."
+
+    def check(self) -> bool:
+        from pdm.project.lockfile import PDMLock
+
+        lockfile = self.project.lockfile
+        if not isinstance(lockfile, PDMLock):  # pragma: no cover
+            return False
+        lockfile_version = lockfile.file_version
+        if not lockfile_version or parse_version(lockfile_version) < parse_version("4.5.0"):
+            return False
+        return FLAG_CROSS_PLATFORM in lockfile.strategy
+
+    def fix(self) -> None:
+        strategies = self.project.lockfile.strategy - {FLAG_CROSS_PLATFORM}
+        lockfile = self.project.lockfile.open_for_write()
+        lockfile["metadata"]["strategy"] = sorted(strategies)
+        self.project.lockfile.write(False)
+        self.log("Lock strategy [success]`cross_platform` has been removed.", verbosity=Verbosity.DETAIL)
